@@ -24,9 +24,10 @@ void ChangePointModelExponential::updateStatistics(const double &obs) {
 
 void ChangePointModelExponential::cpmMLEaux(std::vector <double> &Us) {
 	int i,sz;
-	double n0,n1,s0,s1,K,temp;
+	double n0,n1,s0,s1,K,temp, dsz;
 	Us.reserve(m_statistics[0].size());	
 	sz = m_statistics[0].size();
+  dsz = (double) sz;
     //Us.push_back(0);
     
 	//for (i = 1 ; i < sz-2 ; i++) {
@@ -35,7 +36,7 @@ void ChangePointModelExponential::cpmMLEaux(std::vector <double> &Us) {
 		n1 = (double) sz-n0;
 		s0 = (double) m_statistics[0][i];
 		s1 = (double) m_statistics[0].back() - s0;
-		K = sz*log((double)sz) - n0*log((double)n0)-n1*log((double)n1);
+		K = sz*log(dsz) - n0*log(n0)-n1*log(n1);
 		temp = -sz*log(s0+s1) + n0*log(s0) + n1*log(s1)+K;
 		Us.push_back(-2*temp);    
 	}
